@@ -36,7 +36,7 @@ extern "C" {
 /* The version of the ABI. */
 #define SIP_ABI_MAJOR_VERSION       13
 #define SIP_ABI_MINOR_VERSION       9
-#define SIP_MODULE_PATCH_VERSION    0
+#define SIP_MODULE_PATCH_VERSION    1
 
 
 /*
@@ -44,6 +44,8 @@ extern "C" {
  *
  * v13.9
  *  - Python v3.9 or later is required.
+ *  - Added a new implementation of sipDeprecated() that takes an optional
+ *    supplementary message.
  *
  * v13.8
  *  - Added the 'I' conversion character to the argument and result parsers.
@@ -80,8 +82,8 @@ extern "C" {
 
 
 /* The version of the code generator. */
-#define SIP_VERSION                 0x60807
-#define SIP_VERSION_STR             "6.8.7.dev4+gb31cf6f6.d20241013"
+#define SIP_VERSION                 0x60901
+#define SIP_VERSION_STR             "6.9.1"
 
 /* These are all dependent on the user-specified name of the sip module. */
 #define _SIP_MODULE_FQ_NAME         "PyQt6.sip"
@@ -1428,7 +1430,7 @@ typedef struct _sipAPIDef {
     PyObject *(*api_is_py_method_12_8)(sip_gilstate_t *gil, char *pymc,
             sipSimpleWrapper **sipSelfp, const char *cname, const char *mname);
     sipExceptionHandler (*api_next_exception_handler)(void **statep);
-    void (*unused_private_2)(void);
+    int (*api_deprecated_13_9)(const char *classname, const char *method, const char *message);
     void (*unused_private_3)(void);
     void (*unused_private_4)(void);
     void (*unused_private_5)(void);
